# Copyright 2009-present MongoDB, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Python driver for MongoDB."""

ASCENDING = 1
"""Ascending sort order."""
DESCENDING = -1
"""Descending sort order."""

GEO2D = "2d"
"""Index specifier for a 2-dimensional `geospatial index`_.

.. _geospatial index: http://docs.mongodb.org/manual/core/2d/
"""

GEOHAYSTACK = "geoHaystack"
"""**DEPRECATED** - Index specifier for a 2-dimensional `haystack index`_.

**DEPRECATED** - :attr:`GEOHAYSTACK` is deprecated and will be removed in
PyMongo 4.0. geoHaystack indexes (and the geoSearch command) were deprecated
in MongoDB 4.4. Instead, create a 2d index and use $geoNear or $geoWithin.
See https://dochub.mongodb.org/core/4.4-deprecate-geoHaystack.

.. versionchanged:: 3.11
   Deprecated.

.. _haystack index: http://docs.mongodb.org/manual/core/geohaystack/
"""

GEOSPHERE = "2dsphere"
"""Index specifier for a `spherical geospatial index`_.

.. versionadded:: 2.5

.. _spherical geospatial index: http://docs.mongodb.org/manual/core/2dsphere/
"""

HASHED = "hashed"
"""Index specifier for a `hashed index`_.

.. versionadded:: 2.5

.. _hashed index: http://docs.mongodb.org/manual/core/index-hashed/
"""

TEXT = "text"
"""Index specifier for a `text index`_.

.. seealso:: MongoDB's `Atlas Search
   <https://docs.atlas.mongodb.com/atlas-search/>`_ which offers more advanced
   text search functionality.

.. versionadded:: 2.7.1

.. _text index: http://docs.mongodb.org/manual/core/index-text/
"""

OFF = 0
"""No database profiling."""
SLOW_ONLY = 1
"""Only profile slow operations."""
ALL = 2
"""Profile all operations."""

version_tuple = (3, 11, 4)

def get_version_string():
    if isinstance(version_tuple[-1], str):
        return '.'.join(map(str, version_tuple[:-1])) + version_tuple[-1]
    return '.'.join(map(str, version_tuple))

__version__ = version = get_version_string()
"""Current version of PyMongo."""

from pymongo.collection import ReturnDocument
from pymongo.common import (MIN_SUPPORTED_WIRE_VERSION,
                            MAX_SUPPORTED_WIRE_VERSION)
from pymongo.cursor import CursorType
from pymongo.mongo_client import MongoClient
from pymongo.mongo_replica_set_client import MongoReplicaSetClient
from pymongo.operations import (IndexModel,
                                InsertOne,
                                DeleteOne,
                                DeleteMany,
                                UpdateOne,
                                UpdateMany,
                                ReplaceOne)
from pymongo.read_preferences import ReadPreference
from pymongo.write_concern import WriteConcern

def has_c():
    """Is the C extension installed?"""
    try:
        from pymongo import _cmessage
        return True
    except ImportError:
        return False



# Copyright 2020-present MongoDB, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you
# may not use this file except in compliance with the License.  You
# may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.  See the License for the specific language governing
# permissions and limitations under the License.

import argparse
import logging
import socket

from ssl import CERT_REQUIRED

from pymongo.pyopenssl_context import SSLContext
from pymongo.ssl_support import get_ssl_context

# Enable logs in this format:
# 2020-06-08 23:49:35,982 DEBUG ocsp_support Peer did not staple an OCSP response
FORMAT = '%(asctime)s %(levelname)s %(module)s %(message)s'
logging.basicConfig(format=FORMAT, level=logging.DEBUG)

def check_ocsp(host, port, capath):
    ctx = get_ssl_context(
        None,  # certfile
        None,  # keyfile
        None,  # passphrase
        capath,
        CERT_REQUIRED,
        None,  # crlfile
        True,  # match_hostname
        True)  # check_ocsp_endpoint

    # Ensure we're using pyOpenSSL.
    assert isinstance(ctx, SSLContext)

    s = socket.socket()
    s.connect((host, port))
    try:
        s = ctx.wrap_socket(s, server_hostname=host)
    finally:
        s.close()

def main():
    parser = argparse.ArgumentParser(
        description='Debug OCSP')
    parser.add_argument(
        '--host', type=str, required=True, help="Host to connect to")
    parser.add_argument(
        '-p', '--port', type=int, default=443, help="Port to connect to")
    parser.add_argument(
        '--ca_file', type=str, default=None, help="CA file for host")
    args = parser.parse_args()
    check_ocsp(args.host, args.port, args.ca_file)

if __name__ == '__main__':
     main()




# Copyright 2018-present MongoDB, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import sys

sys.path[0:0] = [""]

from test import client_context, SkipTest, unittest


class TestClientContext(unittest.TestCase):
    def test_must_connect(self):
        if 'PYMONGO_MUST_CONNECT' not in os.environ:
            raise SkipTest('PYMONGO_MUST_CONNECT is not set')

        self.assertTrue(client_context.connected,
                        'client context must be connected when '
                        'PYMONGO_MUST_CONNECT is set. Failed attempts:\n%s' %
                        (client_context.connection_attempt_info(),))

    def test_enableTestCommands_is_disabled(self):
        if 'PYMONGO_DISABLE_TEST_COMMANDS' not in os.environ:
            raise SkipTest('PYMONGO_DISABLE_TEST_COMMANDS is not set')

        self.assertFalse(client_context.test_commands_enabled,
                         'enableTestCommands must be disabled when '
                         'PYMONGO_DISABLE_TEST_COMMANDS is set.')

    def test_setdefaultencoding_worked(self):
        if 'SETDEFAULTENCODING' not in os.environ:
            raise SkipTest('SETDEFAULTENCODING is not set')

        self.assertEqual(
            sys.getdefaultencoding(), os.environ['SETDEFAULTENCODING'])


if __name__ == "__main__":
    unittest.main()
